@@ -26,6 +26,7 @@ let bool_of_string = function
   | x -> failwith (sprintf "Test.bool_of_string: %s neither 0 nor 1" x)
 
 let rank = ref (-1)
+let first_time = ref true
 
 let hello i =
   rank := i;
@@ -35,6 +36,11 @@ let goodbye () =
   eprintf "Goodbye from %d\n%!" !rank
 
 let work a =
+  (* if !first_time then
+   *   begin
+   *     eprintf "My rank is %d\n%!" (Parany.get_rank ());
+   *     first_time := false
+   *   end; *)
   (* if !rank = 8 then failwith "Worker 8 on strike" else *)
   a
 
